Wake Vision is a large, high-quality dataset featuring over 6 million images,
significantly exceeding the scale and diversity of current tinyML datasets
(100x). This dataset includes images with annotations of whether each image
contains a person. Additionally, it incorporates a comprehensive fine-grained
benchmark to assess fairness and robustness, covering perceived gender,
perceived age, subject distance, lighting conditions, and depictions. The Wake
Vision labels are derived from Open Image's annotations which are licensed by
Google LLC under CC BY 4.0 license. The images are listed as having a CC BY 2.0
license. Note from Open Images: "while we tried to identify images that are
licensed under a Creative Commons Attribution license, we make no
representations or warranties regarding the license status of each image and you
should verify the license for each image yourself."
